@@ -12,6 +12,7 @@ using namespace Rcpp;
 arma::mat calculateRMSE(arma::mat Pop, arma::vec EigsData, int NSamples, int NPop, int N) {
 
   arma::mat RMSR_Eigs(NSamples, 1);
+  int I = EigsData.n_elem;
   for (int j = 0; j < NSamples; j++) {
     arma::uvec indices = arma::randi<arma::uvec>(N, arma::distr_param(0, NPop - 1));
     arma::mat Samp = Pop.rows(indices);
@@ -20,7 +21,7 @@ arma::mat calculateRMSE(arma::mat Pop, arma::vec EigsData, int NSamples, int NPo
     Eigs_Samp = sort(Eigs_Samp, "descend");
     double sum_squared_diff = sum(square(Eigs_Samp - EigsData));
 
-    RMSR_Eigs(j, 0) = std::sqrt(sum_squared_diff);
+    RMSR_Eigs(j, 0) = std::sqrt(sum_squared_diff / I);
   }
 
   return RMSR_Eigs;
